/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.examples.mailreaderjpa;

import org.apache.mailreaderjpa.User;
import org.apache.shale.view.AbstractViewController;

/**
 * <p>Backing bean for <code>/logon.jsp</code> view.  Upon completion of a
 * successful logon, a <code>User</code> instance for the logged on user will
 * be stored in the session-scoped <code>state</code> bean.</p>
 */
public class Logon extends AbstractViewController {


    // ------------------------------------------------------- Public Properties


    /**
     * <p>The business {@link Logic} for this application.  This value
     * will be injected, based on the managed bean configuration.</p>
     */
    private Logic logic = null;


    /**
     * <p>Return the business {@link Logic} for this application.</p>
     */
    public Logic getLogic() {
        return this.logic;
    }


    /**
     * <p>Set the business {@link Logic} for this application.</p>
     *
     * @param logic The new business logic instance
     */
    public void setLogic(Logic logic) {
        this.logic = logic;
    }


    /**
     * <p>The per-user {@link State} instance we are associated with.  This
     * value will be injected, based on the managed bean configuration.</p>
     */
    private State state = null;


    /**
     * <p>Return the per-user {@link State} instance we are associated with.</p>
     */
    public State getState() {
        return this.state;
    }


    /**
     * <p>Set the per-user {@link State} instance we are associated with.</p>
     *
     * @param state The new State instance
     */
    public void setState(State state) {
        this.state = state;
    }


    // -------------------------------------------------- Input Field Properties


    private String username;

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    private String password;

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }


    // -------------------------------------------------------- Lifecycle Events


    /**
     * <p>Ensure that the database content has been bootstrapped before
     * we try to authenticate a user.</p>
     */
    public void preprocess() {
        getLogic().bootstrap();
    }


    // ------------------------------------------------------------- View Events


    /**
     * <p>Handle a request to log this user on.</p>
     */
    public String logon() {

        try {
            User user = getLogic().authenticate(getUsername(), getPassword());
            if (user != null) {
                if (user.getPassword().equals(getPassword())) {
                    getState().setUser(user);
                    return "success";
                }
            }
        } catch (Exception e) {
            log("Exception authenticating user", e);
            error("Exception authenticating user: " + e);
            return null;
        }
        error("Invalid username and/or password, please try again");
        return null;

    }


}
